summaryrefslogtreecommitdiffstats
path: root/src/import
diff options
context:
space:
mode:
Diffstat (limited to 'src/import')
-rw-r--r--src/import/chips/p9/procedures/hwp/memory/lib/mc/mc.C9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/import/chips/p9/procedures/hwp/memory/lib/mc/mc.C b/src/import/chips/p9/procedures/hwp/memory/lib/mc/mc.C
index 4cfe78af6..230c109b3 100644
--- a/src/import/chips/p9/procedures/hwp/memory/lib/mc/mc.C
+++ b/src/import/chips/p9/procedures/hwp/memory/lib/mc/mc.C
@@ -68,11 +68,12 @@ enum throttle_enums
MAXALL_MINALL = 0b000,
- //wait 16 refresh intervals of idle before powering down all ranks
- MIN_DOMAIN_REDUCTION_TIME = 0x10,
+ // Wait 959 refresh intervals of idle before powering down all ranks
+ MIN_DOMAIN_REDUCTION_TIME = 959,
- //wait 64 refresh intervals of idle before going into STR on all ranks
- ENTER_STR_TIME = 0x40
+ // Wait 1023 refresh intervals of idle before going into STR on all ranks
+ // 1023 is the max allowed value
+ ENTER_STR_TIME = 1023
};
///
OpenPOWER on IntegriCloud